import * as Lambda from 'aws-lambda';
import { OpenApi } from '../../openapi';
import { OperationParams, RawRequest, RawResponse, RequestParams } from '../../types';
export declare type LambdaHttpEvent = Pick<Lambda.APIGatewayEvent, 'httpMethod' | 'path' | 'multiValueHeaders' | 'headers' | 'queryStringParameters' | 'multiValueQueryStringParameters' | 'body'>;
export declare type LambdaHttpResult = Pick<Lambda.APIGatewayProxyResult, 'statusCode' | 'headers' | 'multiValueHeaders' | 'body'>;
/**
 * AWS Lambda specific request parameters
 * @property event    The Lambda event
 * @property context  The Lambda context
 */
export declare type LambdaSource<Event extends LambdaHttpEvent = Lambda.APIGatewayEvent> = {
    lambda: {
        event: Event;
        context: Lambda.Context;
    };
};
export declare type LambdaContext<T = unknown, Event extends LambdaHttpEvent = Lambda.APIGatewayEvent> = LambdaSource<Event> & T;
export declare type LambdaOperationParams<T = any, Event extends LambdaHttpEvent = Lambda.APIGatewayEvent> = OperationParams<LambdaContext<T, Event>>;
export declare type LambdaRequestParams<T = any, Event extends LambdaHttpEvent = Lambda.APIGatewayEvent> = RequestParams<LambdaContext<T, Event>>;
/**
 * A HTTP API using an OpenAPI definition and implemented using AWS Lambda.
 */
export declare class LambdaOpenApi<T, Event extends LambdaHttpEvent = Lambda.APIGatewayEvent> extends OpenApi<LambdaContext<T, Event>> {
    protected fromLambdaEvent(event: LambdaHttpEvent): RawRequest;
    protected toLambdaResult(res: RawResponse): LambdaHttpResult;
    /**
     * Creates a lambda HTTP event handler function which will route and handle requests using this class
     * and transform the response into a lambda HTTP event response.
     * The request and response body will be converted from/to JSON.
     *
     * @param args  If T is an object, an instance of T, otherwise no parameters
     *
     * @return A lambda event handler function
     */
    eventHandler(...[data]: T extends Record<string, any> ? T[] : []): Lambda.Handler<Event, LambdaHttpResult>;
}
//# sourceMappingURL=lambda-openapi.d.ts.map